Pyortho
======
"""
pyortho: A python package for local signal-and-noise orthogonalization and local similarity calculation (for detecting signal leakage) introduced in Chen and Fomel, 2015, Random noise attenuation using local signal-and-noise orthogonalization, Geophysics, WD1-WD9.

:copyright:
    Initial version: Yangkang Chen (chenyk2016@gmail.com), 2021-2022
	Later version: pyortho developing team, 2022-present
	
:license:
    GNU General Public License, Version 3
    (http://www.gnu.org/copyleft/gpl.html)   
"""

Install:
git clone https://github.com/chenyk1990/pyortho
cd pyortho
pip install -v -e .

or

pip install pyortho

dependence package:
scipy 
numpy 
matplotlib



